Command Line Interface
======================
bioversions automatically installs the command :code:`bioversions`. See
:code:`bioversions --help` for usage details.

.. click:: bioversions.cli:main
   :prog: bioversions
   :show-nested:
